@@ -111,13 +111,10 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         # Load the title and description. Some videos do not have a description, in which case None is returned.
         self.actionUserVideos.setText("%s\'s Videos" % unicode(self.video.media.credit.text, "utf-8"))
-        self.titleLabel.setText(unicode(self.video.title.text, "utf-8"))
-        for link in self.video.link:
-            if link.rel == "self":
-                video_uri = link.href
+        self.titleLabel.setText(unicode(self.video.title.text, "utf-8"))       
         try:
-            if ("playlist" in video_uri and self.video.summary):
-                self.descriptionTextBox.setText(unicode(self.video.summary.text, "utf-8"))
+            if "playlist" in self.video.id.text:
+                self.descriptionTextBox.setText(unicode(self.video.content.text, "utf-8"))
             else:
                 self.descriptionTextBox.setText(unicode(self.video.media.description.text, "utf-8"))
         except:
@@ -328,16 +325,12 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         Raises an EditVideoDialog.
         """
-        for link in self.video.link:
-            if link.rel == "self":
-                video_uri = link.href
-                
-        if "playlist" in video_uri:
-            editVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, video_uri, self.video, self.playlistPosition, self.playlistLength)
+        if "playlist" in self.video.id.text:
+            editVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, self.playlistId, self.video, self.playlistPosition, self.playlistLength)
         else:
             editVideoDialog = cutetubedialogs.EditVideoDialog(self, self.video)
         self.connect(editVideoDialog, SIGNAL("accepted()"), self.loadData)
-        
+
     @pyqtSignature("")
     def on_ratingButton_clicked(self):
         """
