@@ -255,23 +255,19 @@ class YouTubeDataService(object):
         try:
             CutetubeLog.logInfo("Retreiving video URL for \'%s\' (id = %s)" % (video.media.title.text, video.media.player.url.split("=") [1].split("&")[0]))
             videoUrl = ""       
-            playerUrl = video.media.player.url.split("&")[0]
-            html = urllib.urlopen(playerUrl).read()
-            html = "".join(html.split())
+            videoId = video.media.video_id.text
+            html = urllib.urlopen("http://www.youtube.com/get_video_info?&video_id=%s&el=detailpage&ps=default&eurl=&gl=US&hl=en" % videoId).read()
             formats = {}
-            pos = html.find("\",\"fmt_url_map\":\"")
-            if (pos != -1):
-                pos2 = html.find("\"", pos + 17)
-                fmt_map = urllib.unquote(html[pos + 17:pos2]) + ","
-                parts = fmt_map.split("|")
-                key = parts[0]
-                for p in parts[1:]:
-                    idx = p.rfind(",")
-                    value = p[:idx].replace("\\/", "/").replace("\u0026", "&") # Quick and dirty fix
-                    formats[int(key)] = value
-                    key = p[idx + 1:]
-                
-            formatList = [22, 35, 34, 18, 17]
+            html = urllib.unquote(html)
+            pos = html.find("fmt_stream_map=url=") + 19
+            pos2 = html.rfind("&itag=5", pos) + 7
+            fmt_map = html[pos:pos2]
+            parts = fmt_map.split(",url=")
+            for p in parts:
+                value = urllib.unquote(p).replace("%2C", ",").split("&type=video")[0]
+                key = p[p.rfind("=") + 1:]
+                formats[int(key)] = value
+                formatList = [22, 35, 34, 18, 5]
             for format in formatList[formatList.index(videoFormat):]:
                 if videoFormat in formats:
                     videoUrl = formats.get(videoFormat)
